@@ -14,7 +14,39 @@ from connect.eaas.core.utils import client_error_exception_handler
 
 
 class WebAppTestClient(TestClient):
+    """
+    Create a new instance of the WebAppTestClient.
+    The WebAppTestClient is based on the python requests library
+    and will internally create a requests.Session.
+    Each interface method (get, post, ...) accepts the following extra
+    keyword arguments:
 
+    * **context**: an instance of connect.eaas.core.inject.models.Context
+        to provide the endpoint with a specific call context or a dict that will merged
+        with a default context.
+        If this kwarg is omitted a default context is provided.
+    * **installation**: an installation object to receive inside the called endpoint,
+        defaults to None.
+    * **config**: a dictionary with key/value pairs representing environment variables.
+    * **log_level**: allow to simulate a specific log level for such endpoint call
+        default to INFO.
+
+
+    Usage:
+
+    ```python
+    from connect.eaas.core.testing.testclient import WebAppTestClient
+
+    from myext.webapp import MyWebApplication
+
+    client = WebAppTestClient(MyWebApplication)
+    response = client.get('/my/endpoint')
+    ```
+
+    **Parameters:**
+
+    * **webapp** - The web application class.
+    """
     def __init__(self, webapp, base_url='https://example.org/public/v1'):
         self._webapp_class = webapp
         self._app = self._get_application()
@@ -110,14 +142,14 @@ class WebAppTestClient(TestClient):
                 return ConnectClientMocker
 
     def _generate_call_context(self, installation):
-        return Context(**{
-            'installation_id': installation['id'] if installation else 'EIN-000',
+        return {
+            'installation_id': installation['id'] if installation else None,
             'user_id': 'UR-000',
             'account_id': 'VA-000',
             'account_role': 'vendor',
             'call_source': 'ui',
             'call_type': 'user',
-        })
+        }
 
     def _populate_internal_headers(
         self,
@@ -127,12 +159,19 @@ class WebAppTestClient(TestClient):
         context=None,
         log_level=None,
     ):
+
+        if not context:
+            context = Context(**self._generate_call_context(installation))
+        elif isinstance(context, dict):
+            ctx_data = self._generate_call_context(installation)
+            ctx_data.update(context)
+            context = Context(**ctx_data)
+
         headers['X-Connect-Logging-Level'] = log_level or 'INFO'
         if config:
             headers['X-Connect-Config'] = json.dumps(config)
-
-        context: Context = context or self._generate_call_context(installation)
-        headers['X-Connect-Installation-id'] = context.installation_id
+        if context.installation_id:
+            headers['X-Connect-Installation-id'] = context.installation_id
         headers['X-Connect-User-Id'] = context.user_id
         headers['X-Connect-Account-Id'] = context.account_id
         headers['X-Connect-Account-Role'] = context.account_role
